@@ -2,12 +2,10 @@ from __future__ import annotations
 from typing import ClassVar, TypeVar, Any, Union
 from jsonclasses import (jsonclass, ORMObject, ObjectNotFoundException,
                          get_fields)
-from pymongo import ASCENDING
 from pymongo.collection import Collection
 from pymongo.database import Database
 from bson.objectid import ObjectId
 from inflection import pluralize
-from threading import Timer
 from .utils import default_db
 from .encoder import Encoder
 from .query import IDQuery, ListQuery, SingleQuery, OptionalSingleQuery
@@ -39,10 +37,7 @@ class BaseMongoObject(ORMObject):
 
     @classmethod
     def __loaded__(cls: type[T], class_: type[T]) -> None:
-        def __sync():
-            cls._sync_db_settings(class_)
-        timer = Timer(0, __sync)
-        timer.start()
+        cls._sync_db_settings(class_)
 
     @classmethod
     def _sync_db_settings(cls: type[T], class_: type[T]) -> None:
@@ -55,19 +50,21 @@ class BaseMongoObject(ORMObject):
             required = field.fdesc.required
             if unique:
                 if required:
-                    coll.create_index(name,
-                                      ASCENDING,
-                                      unique=True)
+                    iname = coll.create_index(name, unique=True)
+                    print("created index", iname, coll.name)
                 else:
-                    coll.create_index(name,
-                                      ASCENDING,
-                                      unique=True,
-                                      sparse=True)
+                    iname = coll.create_index(name, unique=True, sparse=True)
+                    print("created index", iname, coll.name)
             elif index:
                 if required:
-                    coll.create_index(name, ASCENDING)
+                    iname = coll.create_index(name)
+                    print("created index", iname, coll.name)
                 else:
-                    coll.create_index(name, ASCENDING, sparse=True)
+                    iname = coll.create_index(name, sparse=True)
+                    print("created index", iname, coll.name)
+            else:
+                pass
+                coll.drop_index
 
     def _database_write(self: T) -> None:
         Encoder().encode_root(self).execute()
